/*
Copyright (c) 2018-2019 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import { useStyletron } from '../styles/index.js';
import CellShell from './cell-shell.js';
import { CategoricalFilter } from './column-categorical.js';
import { COLUMNS } from './constants.js';

function BooleanFilter(props) {
  return React.createElement(CategoricalFilter, {
    data: ['true', 'false'],
    close: props.close,
    setFilter: params => {
      const coercedSelection = new Set();
      params.selection.forEach(item => coercedSelection.add(item.toLowerCase() === 'true'));
      props.setFilter({
        selection: coercedSelection,
        exclude: params.exclude,
        description: params.description
      });
    }
  });
}

const BooleanCell = React.forwardRef((props, ref) => {
  const [useCss, theme] = useStyletron();
  return React.createElement(CellShell, {
    ref: ref,
    isMeasured: props.isMeasured,
    isSelected: props.isSelected,
    onSelect: props.onSelect
  }, React.createElement("div", {
    className: useCss({
      textAlign: props.value ? 'right' : 'left',
      minWidth: theme.sizing.scale1400,
      width: '100%'
    })
  }, props.value ? 'T' : 'F'));
});
BooleanCell.displayName = 'BooleanCell';

function BooleanColumn(options) {
  return {
    kind: COLUMNS.BOOLEAN,
    title: options.title,
    sortable: options.sortable === undefined ? true : options.sortable,
    filterable: options.filterable === undefined ? true : options.filterable,
    renderCell: BooleanCell,
    renderFilter: BooleanFilter,
    buildFilter: function (params) {
      return function (data) {
        const included = params.selection.has(data);
        return params.exclude ? !included : included;
      };
    },
    sortFn: function (a, b) {
      if (a === b) return 0;
      return a ? -1 : 1;
    },
    minWidth: options.minWidth
  };
}

export default BooleanColumn;